@@ -20,7 +20,10 @@ extensions = [
     'sphinx.ext.napoleon',
     'sphinx.ext.viewcode',
     'sphinx_autodoc_typehints',
-    'sphinx_autodoc_defaultargs']
+    'sphinx_autodoc_defaultargs',
+    'sphinx_copybutton',
+    'sphinx_reredirects']
+copybutton_prompt_text = ">>> "
 
 source_suffix = '.rst'
 master_doc = 'index'
@@ -28,10 +31,9 @@ project = 'pybliometrics'
 author = 'Michael E. Rose and John Kitchin'
 copyright = f"2017-{date.today().year} {author}"
 
-from pbr.version import VersionInfo
+import pybliometrics
 
-_v = VersionInfo('pybliometrics').semantic_version()
-version = _v.release_string()
+version = pybliometrics.__version__
 
 language = 'en'
 
@@ -56,8 +58,6 @@ html_sidebars = {
         'searchbox.html',
     ]
 }
-html_static_path = ['_static']
-html_css_files = ['custom.css']
 
 # Options for HTMLHelp output
 html_show_sourcelink = True
@@ -113,3 +113,9 @@ texinfo_documents = [
      author, 'pybliometrics', 'One line description of project.',
      'Miscellaneous'),
 ]
+
+# Redirects for moved pages
+redirects = {
+    'reference/scopus/SerialSearch': '/reference/scopus/SerialTitleSearch.html',
+    'reference/scopus/SerialTitle': '/reference/scopus/SerialTitleISSN.html'
+}
