@@ -1,9 +1,4 @@
-import sys
-
-if sys.version_info >= (3, 8):
-    from importlib.metadata import version
-else:
-    from importlib_metadata import version
+from importlib.metadata import version
 
 __version__ = version("pybliometrics")
 
@@ -12,3 +7,5 @@ __citation__ = 'Rose, Michael E. and John R. Kitchin: "pybliometrics: '\
     '10 (2019) 100263.'
 
 import pybliometrics.scopus
+import pybliometrics.sciencedirect
+from pybliometrics.utils.startup import init
