@@ -1,4 +1,4 @@
-from pybliometrics.scopus.utils import *
+from pybliometrics.utils import *
 
 from pybliometrics.scopus.abstract_citation import *
 from pybliometrics.scopus.abstract_retrieval import *
@@ -8,6 +8,6 @@ from pybliometrics.scopus.author_retrieval import *
 from pybliometrics.scopus.author_search import *
 from pybliometrics.scopus.plumx_metrics import *
 from pybliometrics.scopus.scopus_search import *
-from pybliometrics.scopus.serial_search import *
-from pybliometrics.scopus.serial_title import *
+from pybliometrics.scopus.serial_title_search import *
+from pybliometrics.scopus.serial_title_issn import *
 from pybliometrics.scopus.subject_classifications import *
