@@ -1,42 +1,49 @@
-from collections import namedtuple
-from typing import List, NamedTuple, Optional, Tuple, Union
+from typing import NamedTuple
 
-from pybliometrics.scopus.superclasses import Search
-from pybliometrics.scopus.utils import check_integrity, check_parameter_value,\
-    check_field_consistency, make_search_summary
+from pybliometrics.superclasses import Search
+from pybliometrics.utils import check_integrity, check_parameter_value, \
+    check_field_consistency, html_unescape, make_search_summary
+
+
+class Affiliation(NamedTuple):
+    eid: str | None
+    name: str
+    variant: str
+    documents: int
+    city: str | None
+    country: str | None
 
 
 class AffiliationSearch(Search):
     @property
-    def affiliations(self) -> Optional[List[NamedTuple]]:
-        """A list of namedtuples storing affiliation information,
+    def affiliations(self) -> list[Affiliation] | None:
+        """A list of Affiliation namedtuples storing affiliation information,
         where each namedtuple corresponds to one affiliation.
-        The information in each namedtuple is (eid name variant documents city
-        country parent).
+        The information in each namedtuple is `(eid name variant documents city
+        country)`.
 
-        All entries are strings or None.  Field "variant" combines variants
-        of names with a semicolon.
+        All entries are `strings`, `int` or `None`.  Field `variant` combines variants
+        of names with a `";"`.
 
         Raises
         ------
-        ValueError
-            If the elements provided in integrity_fields do not match the
+        `ValueError`
+            If the elements provided in `integrity_fields` do not match the
             actual field names (listed above).
         """
-        # Initiate namedtuple with ordered list of fields
-        fields = 'eid name variant documents city country parent'
-        aff = namedtuple('Affiliation', fields)
+        # Check field consistency
+        fields = 'eid name variant documents city country'
         check_field_consistency(self._integrity, fields)
         # Parse elements one-by-one
         out = []
         for item in self._json:
-            name = item.get('affiliation-name')
-            variants = [d.get('$', "") for d in item.get('name-variant', [])
+            name = item['affiliation-name']
+            variants = [html_unescape(d.get('$', ""))
+                        for d in item.get('name-variant', [])
                         if d.get('$', "") != name]
-            new = aff(eid=item.get('eid'), variant=";".join(variants),
-                      documents=int(item['document-count']), name=name,
-                      city=item.get('city'), country=item.get('country'),
-                      parent=item.get('parent-affiliation-id'))
+            new = Affiliation(eid=item.get('eid'), variant=";".join(variants),
+                      documents=int(item['document-count']), name=html_unescape(name),
+                      city=item.get('city'), country=item.get('country'))
             out.append(new)
         # Finalize
         check_integrity(out, self._integrity, self._action)
@@ -44,12 +51,11 @@ class AffiliationSearch(Search):
 
     def __init__(self,
                  query: str,
-                 refresh: Union[bool, int] = False,
+                 refresh: bool | int = False,
                  verbose: bool = False,
                  download: bool = True,
-                 integrity_fields: Union[List[str], Tuple[str, ...]] = None,
+                 integrity_fields: list[str] | tuple[str, ...] | None = None,
                  integrity_action: str = "raise",
-                 count: int = 200,
                  **kwds: str
                  ) -> None:
         """Interaction with the Affiliation Search API.
@@ -63,31 +69,28 @@ class AffiliationSearch(Search):
         :param download: Whether to download results (if they have not been
                          cached).
         :param integrity_fields: Names of fields whose completeness should
-                                 be checked.  AffiliationSearch will perform
+                                 be checked.  `AffiliationSearch` will perform
                                  the action specified in `integrity_action`
                                  if elements in these fields are missing.
-                                 This helps avoiding idiosynchratically missing
+                                 This helps to avoid idiosynchratically missing
                                  elements that should always be present
                                  (e.g. EID or name).
         :param integrity_action: What to do in case integrity of provided fields
                                  cannot be verified.  Possible actions:
-                                 - "raise": Raise an AttributeError
-                                 - "warn": Raise a UserWarning
-        :param count: (deprecated) The number of entries to be displayed at
-                      once.  A smaller number means more queries with each
-                      query having fewer results.
+                                 - `"raise"`: Raise an AttributeError
+                                 - `"warn"`: Raise a UserWarning
         :param kwds: Keywords passed on as query parameters.  Must contain
                      fields and values mentioned in the API specification at
                      https://dev.elsevier.com/documentation/AffiliationSearchAPI.wadl.
 
         Raises
         ------
-        ScopusQueryError
+        `ScopusQueryError`
             If the number of search results exceeds 5000, which is the API's
             maximum number of results returned.  The error prevents the
             download attempt and avoids making use of your API key.
 
-        ValueError
+        `ValueError`
             If any of the parameters `integrity_action` or `refresh` is not
             one of the allowed values.
 
@@ -100,10 +103,6 @@ class AffiliationSearch(Search):
         # Check
         allowed = ("warn", "raise")
         check_parameter_value(integrity_action, allowed, "integrity_action")
-        if count != 200:
-            msg = "Parameter `count` is deprecated and will be removed in a "\
-                  "future release.  There will be no substitute."
-            warn(msg, FutureWarning)
 
         # Query
         self._action = integrity_action
@@ -111,8 +110,7 @@ class AffiliationSearch(Search):
         self._query = query
         self._refresh = refresh
         self._view = "STANDARD"
-        Search.__init__(self, query=query, api="AffiliationSearch",
-                        count=count, download=download, verbose=verbose, **kwds)
+        Search.__init__(self, query=query, download=download, verbose=verbose, **kwds)
 
     def __str__(self):
         """Return a summary string."""
