@@ -1,32 +1,45 @@
-from collections import namedtuple
-from typing import List, NamedTuple, Optional, Tuple, Union
+from typing import NamedTuple
 
-from pybliometrics.scopus.superclasses import Search
-from pybliometrics.scopus.utils import check_integrity, check_parameter_value,\
-    check_field_consistency, listify, make_search_summary
+from pybliometrics.superclasses import Search
+from pybliometrics.utils import check_integrity, check_parameter_value, \
+    check_field_consistency, get_and_aggregate_subjects, make_search_summary
+
+
+class Author(NamedTuple):
+    eid: str | None
+    orcid: str | None
+    surname: str | None
+    initials: str | None
+    givenname: str | None
+    affiliation: str | None
+    documents: int
+    affiliation_id: str | None
+    city: str | None
+    country: str | None
+    areas: str
 
 
 class AuthorSearch(Search):
     @property
-    def authors(self) -> Optional[List[NamedTuple]]:
+    def authors(self) -> list[Author] | None:
         """A list of namedtuples storing author information,
         where each namedtuple corresponds to one author.
-        The information in each namedtuple is (eid orcid surname initials givenname
-        documents affiliation affiliation_id city country areas).
+        The information in each namedtuple is `(eid orcid surname initials givenname
+        documents affiliation affiliation_id city country areas)`.
 
-        All entries are strings or None.  Areas combines abbreviated subject
-        areas followed by the number of documents in this subject.
+        All entries are `str` or `None`.  Areas combines abbreviated subject
+        areas followed by the number of documents in this subject. The number of 
+        documents on duplicate subject areas is summed up.
 
         Raises
         ------
         ValueError
-            If the elements provided in integrity_fields do not match the
+            If the elements provided in `integrity_fields` do not match the
             actual field names (listed above).
         """
         # Initiate namedtuple with ordered list of fields
         fields = 'eid orcid surname initials givenname affiliation documents '\
                  'affiliation_id city country areas'
-        auth = namedtuple('Author', fields)
         check_field_consistency(self._integrity, fields)
         # Parse elements one-by-one
         out = []
@@ -35,9 +48,9 @@ class AuthorSearch(Search):
             aff = item.get('affiliation-current', {})
             fields = item.get('subject-area',
                               [{'@abbrev': '', '@frequency': ''}])
-            areas = [f"{d.get('@abbrev', '')} ({d.get('@frequency', '')})"
-                     for d in listify(fields)]
-            new = auth(eid=item.get('eid'),
+            subjects = get_and_aggregate_subjects(fields)
+            areas = [f"{abbrev} ({'' if freq == 0 else freq})" for abbrev, freq in subjects.items()]
+            new = Author(eid=item.get('eid'),
                        orcid=item.get('orcid'),
                        initials=name.get('initials'),
                        surname=name.get('surname'),
@@ -55,12 +68,11 @@ class AuthorSearch(Search):
 
     def __init__(self,
                  query: str,
-                 refresh: Union[bool, int] = False,
+                 refresh: bool | int = False,
                  verbose: bool = False,
                  download: bool = True,
-                 integrity_fields: Union[List[str], Tuple[str, ...]] = None,
+                 integrity_fields: list[str] | tuple[str, ...] | None = None,
                  integrity_action: str = "raise",
-                 count: int = 200,
                  **kwds: str
                  ) -> None:
         """Interaction with the Author Search API.
@@ -68,25 +80,22 @@ class AuthorSearch(Search):
         :param query: A string of the query.  For allowed fields and values see
                       https://dev.elsevier.com/sc_author_search_tips.html.
         :param refresh: Whether to refresh the cached file if it exists or not.
-                        If int is passed, cached file will be refreshed if the
+                        If `int` is passed, cached file will be refreshed if the
                         number of days since last modification exceeds that value.
         :param download: Whether to download results (if they have not been
                          cached).
         :param verbose: Whether to print a download progress bar.
         :param integrity_fields: Names of fields whose completeness should
-                                 be checked.  ScopusSearch will perform the
+                                 be checked.  `ScopusSearch` will perform the
                                  action specified in `integrity_action` if
                                  elements in these fields are missing.  This
-                                 helps avoiding idiosynchratically missing
+                                 helps to avoid idiosynchratically missing
                                  elements that should always be present
                                  (e.g., EID or source ID).
         :param integrity_action: What to do in case integrity of provided fields
                                  cannot be verified.  Possible actions:
-                                 - "raise": Raise an AttributeError
-                                 - "warn": Raise a UserWarning
-        :param count: (deprecated) The number of entries to be displayed at
-                      once.  A smaller number means more queries with each
-                      query having fewer results.
+                                 - `"raise"`: Raise an `AttributeError`
+                                 - `"warn"`: Raise a `UserWarning`
         :param kwds: Keywords passed on as query parameters.  Must contain
                      fields and values mentioned in the API specification at
                      https://dev.elsevier.com/documentation/AuthorSearchAPI.wadl.
@@ -111,10 +120,6 @@ class AuthorSearch(Search):
         # Checks
         allowed = ("warn", "raise")
         check_parameter_value(integrity_action, allowed, "integrity_action")
-        if count != 200:
-            msg = "Parameter `count` is deprecated and will be removed in a "\
-                  "future release.  There will be no substitute."
-            warn(msg, FutureWarning)
 
         # Query
         self._action = integrity_action
@@ -122,8 +127,7 @@ class AuthorSearch(Search):
         self._query = query
         self._refresh = refresh
         self._view = "STANDARD"
-        Search.__init__(self, query=query, api='AuthorSearch', count=count,
-                        download=download, verbose=verbose, **kwds)
+        Search.__init__(self, query=query, download=download, verbose=verbose, **kwds)
 
     def __str__(self):
         """Print a summary string."""
