@@ -1,36 +1,45 @@
-from collections import namedtuple
-from typing import List, NamedTuple, Optional, Union
+from typing import NamedTuple
 
-from pybliometrics.scopus.superclasses import Retrieval
-from pybliometrics.scopus.utils import check_parameter_value
+from pybliometrics.superclasses import Retrieval
+from pybliometrics.utils import check_parameter_value
+
+
+class Category(NamedTuple):
+    name: str
+    total: int
+
+
+class Metric(NamedTuple):
+    name: str
+    total: int
 
 
 class PlumXMetrics(Retrieval):
     @property
-    def category_totals(self) -> Optional[List[NamedTuple]]:
+    def category_totals(self) -> list[Category] | None:
         """A list of namedtuples representing total metrics as categorized
-        by PlumX Metrics in the form (capture, citation, mention, socialMedia,
-        usage).
+        by PlumX Metrics in the form `(capture, citation, mention, socialMedia,
+        usage)`.
 
         Note: For Citation category a maximum citation count across sources
         is shown.  For details on PlumX Metrics categories see
         https://plumanalytics.com/learn/about-metrics/.
         """
         categories = self._json.get('count_categories', [])
-        return _format_as_namedtuple_list(categories, "Category") or None
+        return _format_as_category_list(categories) or None
 
     @property
-    def capture(self) -> Optional[List[NamedTuple]]:
+    def capture(self) -> list[Metric] | None:
         """A list of namedtuples representing metrics in the Captures category.
 
         Note: For details on Capture metrics see
         https://plumanalytics.com/learn/about-metrics/capture-metrics/.
         """
         metrics = self._count_categories.get('capture', [])
-        return _format_as_namedtuple_list(metrics) or None
+        return _format_as_metric_list(metrics) or None
 
     @property
-    def citation(self) -> Optional[List[NamedTuple]]:
+    def citation(self) -> list[Metric] | None:
         """A list of namedtuples representing citation counts from
         different sources.
 
@@ -41,83 +50,58 @@ class PlumXMetrics(Retrieval):
         for item in self._count_categories.get('citation', []):
             if item.get('sources'):
                 metrics += item['sources']
-        return _format_as_namedtuple_list(metrics) or None
+        return _format_as_metric_list(metrics) or None
 
     @property
-    def mention(self) -> Optional[List[NamedTuple]]:
+    def mention(self) -> list[Metric] | None:
         """A list of namedtuples representing metrics in Mentions category.
 
         Note: For details on Mention metrics see
         https://plumanalytics.com/learn/about-metrics/mention-metrics/.
         """
         metrics = self._count_categories.get('mention', [])
-        return _format_as_namedtuple_list(metrics) or None
+        return _format_as_metric_list(metrics) or None
 
     @property
-    def social_media(self) -> Optional[List[NamedTuple]]:
+    def social_media(self) -> list[Metric] | None:
         """A list of namedtuples representing social media metrics.
 
         Note: For details on Social Media metrics see
         https://plumanalytics.com/learn/about-metrics/social-media-metrics/.
         """
         metrics = self._count_categories.get('socialMedia', [])
-        return _format_as_namedtuple_list(metrics) or None
+        return _format_as_metric_list(metrics) or None
 
     @property
-    def usage(self) -> Optional[List[NamedTuple]]:
+    def usage(self) -> list[Metric] | None:
         """A list of namedtuples representing Usage category metrics.
 
         Note: For details on Usage metrics see
         https://plumanalytics.com/learn/about-metrics/usage-metrics/.
         """
         metrics = self._count_categories.get('usage', [])
-        return _format_as_namedtuple_list(metrics) or None
+        return _format_as_metric_list(metrics) or None
 
     def __init__(self,
                  identifier: str,
                  id_type: str,
-                 refresh: Union[bool, int] = False,
+                 refresh: bool | int = False,
                  **kwds: str
                  ) -> None:
         """Interaction with the PlumX Metrics API.
 
         :param identifier: The identifier of a document.
         :param id_type: The type of used ID. Allowed values are:
-                        - 'airitiDocId'
-                        - 'arxivId'
-                        - 'cabiAbstractId'
-                        - 'citeulikeId'
-                        - 'digitalMeasuresArtifactId'
-                        - 'doi'
-                        - 'elsevierId'
-                        - 'elsevierPii'
-                        - 'facebookCountUrlId'
-                        - 'figshareArticleId'
-                        - 'githubRepoId'
-                        - 'isbn'
-                        - 'lccn'
-                        - 'medwaveId'
-                        - 'nctId'
-                        - 'oclc'
-                        - 'pittEprintDscholarId'
-                        - 'pmcid'
-                        - 'pmid'
-                        - 'redditId'
-                        - 'repecHandle'
-                        - 'repoUrl'
-                        - 'scieloId'
-                        - 'sdEid'
-                        - 'slideshareUrlId'
-                        - 'smithsonianPddrId'
-                        - 'soundcloudTrackId'
-                        - 'ssrnId'
-                        - 'urlId'
-                        - 'usPatentApplicationId'
-                        - 'usPatentPublicationId'
-                        - 'vimeoVideoId'
-                        - 'youtubeVideoId'
+                        'airitiDocId'; 'cabiAbstractId'; 'citeulikeId';
+                        'digitalMeasuresArtifactId'; 'doi'; 'elsevierId';
+                        'elsevierPii'; 'facebookCountUrlId';
+                        'figshareArticleId'; 'isbn'; 'lccn'; 'medwaveId';
+                        'nctId'; 'oclc'; 'pittEprintDscholarId'; 'pmcid';
+                        'pmid'; 'redditId'; 'repecHandle'; 'repoUrl';
+                        'scieloId'; 'sdEid'; 'slideshareUrlId';
+                        'smithsonianPddrId'; 'ssrnId'; 'urlId'
         :param refresh: Whether to refresh the cached file if it exists or not.
-                        If int is passed, cached file will be refreshed if the
+                        If `int` is passed, cached file will be refreshed if the
                         number of days since last modification exceeds that value.
         :param kwds: Keywords passed on as query parameters.  Must contain
                      fields and values mentioned in the API specification at
@@ -134,16 +118,13 @@ class PlumXMetrics(Retrieval):
         where `path` is specified in your configuration file.
         """
         # Checks
-        allowed = ('airitiDocId', 'arxivId', 'cabiAbstractId',
-                   'citeulikeId', 'digitalMeasuresArtifactId', 'doi',
-                   'elsevierId', 'elsevierPii', 'facebookCountUrlId',
-                   'figshareArticleId', 'githubRepoId', 'isbn',
-                   'lccn', 'medwaveId', 'nctId', 'oclc',
+        allowed = ('airitiDocId', 'cabiAbstractId', 'citeulikeId',
+                   'digitalMeasuresArtifactId', 'doi', 'elsevierId',
+                   'elsevierPii', 'facebookCountUrlId', 'figshareArticleId',
+                   'isbn', 'lccn', 'medwaveId', 'nctId', 'oclc',
                    'pittEprintDscholarId', 'pmcid', 'pmid', 'redditId',
                    'repecHandle', 'repoUrl', 'scieloId', 'sdEid',
-                   'slideshareUrlId', 'smithsonianPddrId', 'soundcloudTrackId',
-                   'ssrnId', 'urlId', 'usPatentApplicationId',
-                   'usPatentPublicationId', 'vimeoVideoId', 'youtubeVideoId')
+                   'slideshareUrlId', 'smithsonianPddrId', 'ssrnId', 'urlId')
         check_parameter_value(id_type, allowed, "id_type")
         self._id_type = id_type
         self._identifier = identifier
@@ -151,8 +132,7 @@ class PlumXMetrics(Retrieval):
         # Load json
         self._refresh = refresh
         self._view = 'ENHANCED'
-        Retrieval.__init__(self, identifier=identifier, id_type=id_type,
-                           api='PlumXMetrics', **kwds)
+        Retrieval.__init__(self, identifier=identifier, id_type=id_type, **kwds)
         cats = self._json.get('count_categories', [])
         self._count_categories = {d["name"]: d['count_types'] for d in cats}
 
@@ -166,9 +146,11 @@ class PlumXMetrics(Retrieval):
         return s
 
 
-def _format_as_namedtuple_list(metric_counts, tuple_name='Metric'):
-    """Formats list of dicts of metrics into list of namedtuples in the
-    form (name, total).
-    """
-    metric = namedtuple(tuple_name, 'name total')
-    return [metric(name=t['name'], total=t['total']) for t in metric_counts]
+def _format_as_category_list(metric_counts):
+    """Formats list of dicts of metrics into list of Category namedtuples."""
+    return [Category(name=t['name'], total=t['total']) for t in metric_counts]
+
+
+def _format_as_metric_list(metric_counts):
+    """Formats list of dicts of metrics into list of Metric namedtuples."""
+    return [Metric(name=t['name'], total=t['total']) for t in metric_counts]
